@@ -117,7 +117,7 @@ def validate_sensi_config(filepath):
             if not incorrect_values.empty:
                 return "'Sensi_config.csv': 'Apply stress' has incorrect entry at row(s) {}".format(
                     list(incorrect_values.index.values))
-
+                    
     return sensi_config
 
 
@@ -190,10 +190,15 @@ def read_sensitivities(env_dir):
     for sensi in sensi_names:
         sensi_list[sensi] = list(sensi_config["Stress name"][ (sensi_config["Scenario"] == sensi) & (sensi_config["Apply stress"] == True) ])
 
-    # TODO: To cross check the Stress names in the Sensi_param -> To add a unit test
-    # Check if colmuns of sensi_config['Stress name'] values all are columns in sensi_param
-    if not set(sensi_config['Stress name']).issubset(set(sensi_param.columns)):
-        raise SensiIOError("Columns {} in sensi_param do not match the values in sensi_config".format(sensi_config['Stress name'] - set(sensi_param.columns)))
+    sensi_param_stresses = set(sensi_param.columns)
+    sensi_param_stresses.remove("Name")
+
+    # Checks if colmuns of sensi_config['Stress name'] values all are columns in sensi_param by
+    # verifying that sensi_config['Stress name'] are contained in sensi_param.columns
+    if sensi_param_stresses is None :
+        raise SensiIOError("Sensi_config do not contain any stresses from Sensi_param")
+    if not set(sensi_config['Stress name']).issubset(sensi_param_stresses):
+        raise SensiIOError("Columns {} in Sensi_param do not match the stresses in sensi_config".format(set(sensi_config['Stress name']) - sensi_param_stresses))
 
     param_map_unsorted = {}
 
@@ -239,12 +244,13 @@ def create_one_sensi_from_base(sensi_name, base_dir, sensi_path=None, logger=Non
             return SensiIOError(f"Unable to copy files to {sensi_name}: {exc}")
 
         try:
-            settings_json_patj = f"{sensi_path}/resources/settings.json"
-            settings_json_sensi = read_json_file(settings_json_patj)
-            settings_json_sensi['gen_param']['name'] = sensi_name
+            settings_json_path = f"{sensi_path}/resources/settings.json"
+            settings_json_sensi = read_json_file(settings_json_path)
+            settings_json_sensi['gen_param']['name'] = '{}_{}'.format(settings_json_sensi['gen_param']['name'], sensi_name)
             settings_json_sensi['gen_param']['path'] = sensi_path
+            settings_json_sensi['framework']['sensi_1']['name'] = sensi_name
             log(f"Writing settings.json to {sensi_path}", logger)
-            with open(settings_json_patj, 'w') as f:
+            with open(settings_json_path, 'w') as f:
                 f.write(json.dumps(settings_json_sensi, indent=4))
         except Exception as err:
             log(f"Exception {err}", logger)
@@ -280,7 +286,8 @@ class SensiConfig:
         if len(self.sensi_list)>0:
             if len(sensi_dirs)>0:
                 for sensi in self.sensi_list.keys():
-                    if sensi in sensi_dirs.keys():
+                    # Checks that it is a sensi in the specified sensi lists (i.e. sensi_dirs) and that there is at least one stress name to apply for it.
+                    if sensi in sensi_dirs.keys() and len(self.sensi_list[sensi]) > 0:
                         log(f"Creating sensi {sensi} from base table {self.base_dir} to {sensi_dirs[sensi]}", self.logger)
                         res = create_one_sensi_from_base(sensi, self.base_dir, sensi_dirs[sensi], self.logger)
                         if res is not None:
@@ -289,9 +296,10 @@ class SensiConfig:
                 path = Path(self.base_dir)
                 parent_dir = path.parent
                 for sensi in self.sensi_list.keys():
-                    res = create_one_sensi_from_base(sensi, self.base_dir, os.path.join(parent_dir, sensi))
-                    if res is not None:
-                        processed_sensi_dirs[sensi] = res
+                    if len(self.sensi_list[sensi]) > 0:
+                        res = create_one_sensi_from_base(sensi, self.base_dir, os.path.join(parent_dir, sensi))
+                        if res is not None:
+                            processed_sensi_dirs[sensi] = res
 
         return processed_sensi_dirs
 
