@@ -1,6 +1,7 @@
 import os
 import re
 import numpy as np
+from numpy.lib.function_base import select
 
 from objectpath import *
 
@@ -345,28 +346,25 @@ def apply_syntax_to_file(input_path, syntax, settings_json):
             if os.path.exists(input_path):
                 input_df = pd.read_csv(input_path, sep=col_sep)
 
-                selected_df = None
                 if syntax.condition:
                     # # print(syntax.condition)
                     condition = syntax.condition.strip('()')
                     or_conditions = condition.split('||')
-                    df_or_list = []
+                    df_indexes_list_or = []
                     for or_cond in or_conditions:
                         if or_cond.strip():
                             and_conditions = or_cond.split('&&')
-                            df_and_list = []
+                            df_indexes_list_and = []
                             for and_cond in and_conditions:
                                 selected_df = interpret_condition(and_cond, input_df)
-                                df_and_list.append(selected_df)
+                                df_indexes_list_and.append(set(selected_df.index))
 
-                            # TODO by Quincy: CHANGE merge to using conditions and selection with pandas
-                            df_merge = df_and_list[0]
-                            for df in df_and_list[1:]:
-                                df_merge = pd.merge(df_merge, df, how='inner')
-                            df_or_list.append(df_merge)
+                            #TODO by Quincy: CHANGE merge to using conditions and selection with pandas
+                            df_common_indexes = set.intersection(*df_indexes_list_and)
+                            df_indexes_list_or.append(df_common_indexes)
 
-                    # print("Condition: ", syntax.condition, end=", ")
-                    df_concat = pd.concat(df_or_list)
+                    df_total_indexes = set().union(*df_indexes_list_or)
+                    df_concat = input_df.iloc[list(df_total_indexes)]
 
                 if syntax.col:
                     # print(syntax.col)
@@ -386,7 +384,7 @@ def apply_syntax_to_file(input_path, syntax, settings_json):
                     selected_dict = selected_df.to_dict()
                     if syntax.value:
                         applied_dict = apply_value_to_selection(syntax.value, selected_dict)
-
+                        
                     # print("Value: ", syntax.value)
                     # # print(applied_dict)
                     # input_df = input_df.replace(applied_dict)
@@ -397,7 +395,7 @@ def apply_syntax_to_file(input_path, syntax, settings_json):
 
                     # print(input_df)
                     os.remove(input_path)
-                    input_df.to_csv(input_path, sep=col_sep, index=False)
+                    input_df.to_csv(input_path, sep=col_sep, index=False, float_format='%g')
                     return True
                 else:
                     raise SensiSyntaxError("No col found for selection")
